


SNMP_API(3)                                           SNMP_API(3)


NAME
       snmp_open,      snmp_close,      snmp_send,     snmp_read,
       snmp_free_pdu, snmp_select_info, snmp_timeout -  send  and
       receive SNMP messages

SYNOPSIS
       #include <sys/types>
       #include <netinet/in.h>
       #include <sys/time.h>
       #include <snmp/snmp.h>
       #include <snmp/snmp_impl.h>
       #include <snmp/asn1.h>
       #include <snmp/snmp_api.h>

       extern int snmp_errno;

       extern int snmp_dump_packet;

       struct snmp_session *snmp_open(session)
       struct snmp_session *session;

       int snmp_close(session)
       struct snmp_session *session;

       int snmp_send(session, pdu)
       struct snmp_session *session;
       struct snmp_pdu *pdu;

       void snmp_read(fdset)
       fd_set *fdset;

       int snmp_select_info(numfds, fdset, timeout, block)
       int *numfds;
       fd_set *fdset;
       struct timeval *timeout;
       int *block;

       void snmp_timeout()

       void snmp_pdu_create(tag)
       int tag;

       void snmp_free_pdu(pdu)
       struct snmp_pdu *pdu;


DESCRIPTION
       Snmp_open,  snmp_close, and snmp_send each take as input a
       pointer to an object with  the  following  structure.   In
       addition,  snmp_open  also  returns a pointer to an object
       with this structure.  This structure contains  information
       for  a  set of transactions that will share similar trans-
       port characteristics.

       typedef struct sockaddr_in  ipaddr;

       struct snmp_session {
           u_char  *community;      /* community for outgoing requests. */
           int     community_len;   /* Length of community name. */
           int     retries;         /* Number of retries before timeout. */
           long    timeout;         /* Number of uS until first timeout,
                                       then exponential backoff */
           char    *peername;       /* Domain name or dotted IP address
                                       of default peer */
           u_short remote_port;     /* UDP port number of peer. */
           u_short local_port;      /* My UDP port number, 0 for default,
                                       picked randomly */

           /* Authentication function or NULL if null authentication is used */
           u_char  *(*authenticator)();

           int     (*callback)();   /* Function to interpret incoming data */

           /* Pointer to data that the callback function may consider
              important */
           void    *callback_magic;

           int        version;  /* SNMP version number */

           /* fields to support SNMPv1 community model */
           int           community_len;
           u_char      *community;

           /* the private keys to use for user-based security */
           u_char     authKey[16];
           u_char     privKey[16];

           /* fields to support user-based security model in SNMPv2 */
           Parameters params;

           u_char     qoS;
           u_char     agentID[16];
           u_long     agentBoots;
           int        agentTime;          /* the agentTime value */
           int        agentClock;         /* the running agentClock */
           int             userLen;
           u_char     userName[32];
           int        MMS;
           int        contextLen;
           u_char     contextSelector[64];

           /* misc stuff */
           int        readView;
           int        writeView;
       };

       /*
        * Set fields in session and pdu to the following to get a default
        * or unconfigured value.
        */
       #define SNMP_DEFAULT_COMMUNITY_LEN  0  /* for default community name */
       #define SNMP_DEFAULT_RETRIES        -1
       #define SNMP_DEFAULT_TIMEOUT        -1
       #define SNMP_DEFAULT_REMPORT        0
       #define SNMP_DEFAULT_REQID          0
       #define SNMP_DEFAULT_ERRSTAT        -1
       #define SNMP_DEFAULT_ERRINDEX       -1
       #define SNMP_DEFAULT_ADDRESS        0
       #define SNMP_DEFAULT_PEERNAME       NULL
       #define SNMP_DEFAULT_ENTERPRISE_LENGTH  0
       #define SNMP_DEFAULT_TIME           0

       /*
        * This routine must be supplied by the application:
        *
        * u_char *authenticator(pdu, length, community, community_len)
        * u_char *pdu;         The rest of the PDU to be authenticated
        * int *length;         The length of the PDU (updated by the
        *             authenticator)
        * u_char *community;   The community name to authenticate under.
        * int  community_len   The length of the community name.
        *
        * Returns the authenticated pdu, or NULL if authentication failed.
        * If null authentication is used, the authenticator in snmp_session
        * can be set to NULL(0).
        */

       /*
        * This routine must be supplied by the application:
        *
        * int callback(operation, session, reqid, pdu, magic)
        * int operation;
        * struct snmp_session *session;    The session authenticated under.
        * int reqid;                       The request id of this pdu
        *                      (0 for TRAP)
        * struct snmp_pdu *pdu;            The pdu information.
        * void *magic                      A link to the data for this routine.
        *
        * Returns 1 if request was successful, 0 if it should be kept pending.
        * Any data in the pdu must be copied because it will be freed
        * elsewhere.
        * Operations are defined below:
        */
       #define RECEIVED_MESSAGE   1
       #define TIMED_OUT          2

Snmp_send and snmp_free_pdu each take as input a  pointer  to  an
object  with  the  following  structure.  This structure contains
information that describes a transaction that will  be  performed
over an open session.

       struct snmp_pdu {
           ipaddr  address;          /* Address of peer */

           int     command;          /* Type of this PDU */

           u_long  reqid;            /* Request id */
           u_long  errstat;          /* Error status */
           u_long  errindex;         /* Error index */

           /* Trap information */
           oid     *enterprise;      /* System OID */
           int     enterprise_length;
           ipaddr  agent_addr;       /* address of object generating trap */
           int     trap_type;        /* trap type */
           int     specific_type;    /* specific type */
           u_long  time;             /* Uptime */

           struct variable_list *variables;
       };


       struct variable_list {
           struct variable_list *next_variable;   /* NULL for last variable */
           oid     *name;                  /* Object identifier of variable */
           int     name_length;            /* number of subid's in name */
           u_char  type;                   /* ASN type of variable */
           union { /* value of variable */
               long    *integer;
               u_char  *string;
               oid     *objid;
           } val;
           int     val_len;
       };

Snmp_read,  snmp_select_info,  and snmp_timeout provide an inter-
face for the use of the select(2) system call so that SNMP trans-
actions can occur asynchronously.

Snmp_select_info  is  given  the information that would have been
passed to select in the absence of SNMP.  For example, this might
include  window update information.  This information is modified
so that SNMP will get the service it requires from  the  call  to
select.   In  this case, numfds, fdset, and timeout correspond to
the nfds, readfds, and timeout arguments to select, respectively.
The  only exception is that timeout must always point to an allo-
cated (but perhaps uninitialized)  struct  timeval.   If  timeout
would have been passed as NULL, block is set to true, and timeout
is treated as undefined.  This same rule applies upon return from
snmp_select_info.

After   calling  snmp_select_info,  select  is  called  with  the
returned data.  When select returns, snmp_read is called with the
fd_set  returned  from  select.   This will read all SNMP sockets
with input.  If select times out, snmp_timeout should  be  called
to see if the timeout was intended for SNMP.


DIAGNOSTICS
       Error  return status from snmp_open is indicated by return
       of a null pointer.  Error return  status  from  snmp_close
       and  snmp_send  is indicated by return of 0.  A successful
       status will return a 1.  The external  integer  snmp_errno
       may then be checked to see what type of error has occurred

       snmp_errno can have the following values:

              SNMPERR_GENERR       A generic error occurred.

              SNMPERR_BAD_LOCPORT  The local port was bad because
                                   it  had already been allocated
                                   or permission was denied.

              SNMPERR_BAD_ADDRESS  The host name or address given
                                   was not useable.

              SNMPERR_BAD_SESSION  The  specified session was not
                                   open.

       The variable snmp_dump_packet can be set to a value  !=  0
       to force hex dumps of packets sent/read.
       Please  Note:  In  the linux port this variable is part of
       the library and should not be declared by the application.

SEE ALSO
       select(2), snmp_api.h
