#ifndef _SNMP_H_
#define _SNMP_H_

/**********************************************************************
 *
 *           Copyright 1998 by Carnegie Mellon University
 * 
 *                       All Rights Reserved
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation, and that the name of CMU not be
 * used in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.
 * 
 * CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
 * CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
 * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 * SOFTWARE.
 * 
 * $Id: snmp.h,v 1.12 1998/05/06 04:07:14 ryan Exp $
 * 
 **********************************************************************/

/*
 * Definitions for the Simple Network Management Protocol (RFC 1067).
 */
#ifdef __cplusplus
extern "C" {
#endif

#include <string.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <tcp.h>

#include <snmp_src/asn1.h>
#include <snmp_src/error.h>
#include <snmp_src/extra.h>
#include <snmp_src/impl.h>
#include <snmp_src/parse.h>
#include <snmp_src/dump.h>
#include <snmp_src/debug.h>

#include <snmp_src/vars.h>
#include <snmp_src/pdu.h>
#include <snmp_src/msg.h>
#include <snmp_src/session.h>
#include <snmp_src/coexist.h>
#include <snmp_src/version.h>
#include <snmp_src/md5.h>
#include <snmp_src/usec.h>

#include <snmp_src/api.h>
#include <snmp_src/api_util.h>
#include <snmp_src/api_err.h>
#include <snmp_src/client.h>
#include <snmp_src/mclient.h>
#include <snmp_src/internal.h>
#include <snmp_src/mib.h>
#include <snmp_src/mibii.h>
#include <snmp_src/compat.h>

#undef READ
#undef WRITE
#undef RESERVE1
#undef RESERVE2
#undef COMMIT
#undef FREE
#undef RONLY
#undef RWRITE
#undef NOACCESS

#define READ  1
#define WRITE 0

#define RESERVE1  0
#define RESERVE2  1
#define COMMIT    2
#define FREE      3

#define RONLY     0xAAAA       /* read access for everyone */
#define RWRITE    0xAABA       /* add write access for community private */
#define NOACCESS  0x0000       /* no access for anybody */

#ifdef __cplusplus
}
#endif

#endif
