
SNMP(3)                                                   SNMP(3)


NAME
       SNMP -  Simple Network Management Protocol

DESCRIPTION
       The  Carnegie  Mellon  SNMP  library is broken up into the
       following parts:

       snmp_api
            Session Management API

       snmp_api_errors
            API Error Functions

       snmp_client
            Client communication routines

       snmp_coexistance
            V1/V2 Coexistance Functions

       snmp_error
            PDU Error Functions

       snmp_extra
            Miscellaneous Functions

       snmp_mib
            MIB Dependant Functions

       snmp_mibii
            MIBII glue

       snmp_mini_client
            Mini-client

       snmp_msg
            Message Encoding / Decoding Functions

       snmp_packet_dump
            Network Packet Dumping Functions

       snmp_pdu
            PDU Functions

       snmp_vars
            Variable Bindings Functions

       snmp_version_info
            Version Information

ENVIRONMENT
       MIBFILE:  Location of the SNMP MIB.

FILES
       mib.txt                   First MIB tried if env. var is not set
       /etc/mib.txt              Second MIB tried if env. var is not set

RFCS
       Related RFCs: 1065, 1066, 1067
       Related SNMPv2 RFCs: 1901, 1902, 1902, 1904,  1905,  1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp

SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)


SNMP_CLIENT(3)                                     SNMP_CLIENT(3)


NAME
       snmp_synch_input,  snmp_synch_response, snmp_synch_setup -
       SNMP Session Synchronization

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       int snmp_synch_input(int Operation, struct snmp_session  *
       Session,  int  RequestID,  struct  snmp_pdu  * PDU, void *
       Magic);

       int  snmp_synch_response(struct  snmp_session  *  Session,
       struct snmp_pdu * PDU, struct snmp_pdu ** ResponseP);

       void   snmp_synch_setup(struct   snmp_session   *Session);
       snmp_synch_input() is called  when  a  registered  session
       receives  an update.  Operation specifies what has occured
       (TIMED_OUT or RECEIVED_MESSAGE).  Session is the  session,
       RequestID  is the reqid of the PDU in question, PDU is the
       PDU in question, and Magic is a  pointer  to  the  current
       state of that session.

       snmp_synch_response() is a quick way to send PDU over ses-
       sion Session and wait for a response.  The  response  will
       be pointed to by ResponsePDUP.

       snmp_synch_setup()  sets  up  session Session for use with
       these functions.

RETURN VALUES
       snmp_synch_input() returns 0 upon error, 1 otherwise.

       snmp_synch_response()   returns    either    STAT_SUCCESS,
       STAT_TIMEOUT, or STAT_ERROR.

RFCS
       Related RFCs: 1065, 1066, 1067
       Related  SNMPv2  RFCs: 1901, 1902, 1902, 1904, 1905, 1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp

SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)


SNMP_EXTRA(3)                                       SNMP_EXTRA(3)


NAME
       uptime_string,  myaddress,  mib_TxtToOid,  mib_OidToTxt  -
       Useful functions

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       char *uptime_string(unsigned int timeticks, char * buf);

       unsigned int myaddress(void);

       int mib_TxtToOid(char * Buf, oid ** OidP, int * LenP);

       int  mib_OidToTxt(oid  *  O,  int  OLen,  char  *Buf,  int
       BufLen);

DESCRIPTION
       uptime_string()  converts  the  value  of timeticks into a
       readable string.  This function assumes that timeticks  is
       of SMI type TimeTicks (Centi-seconds).

       myaddress()  returns  the IP address of the current active
       interface.

       mib_TxtToOid and mib_OidToTxt convert between ASN oids and
       textual strings (IE: ".1.3.6").

       mib_TxtToOid  allocates  space  for  the ASN oid, and this
       space must later be free()'d.

       mib_OidToTxt  starts  filling  the  specified  buffer  (of
       length BufLen) until it runs out of space, or finishes.

RETURN VALUE
       uptime_string() returns the filled buffer.

       myaddress() returns the IP address, or 0.

       mib_TxtToOid() and mib_OidToTxt() return 1 upon success, 0
       otherwise.

RFCS
       Related RFCs: 1065, 1066, 1067
       Related SNMPv2 RFCs: 1901, 1902, 1902, 1904,  1905,  1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp


SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)



SNMP_MIBII(3)                                       SNMP_MIBII(3)


NAME
       snmpInASNParseErrs,  snmpInASNParseErrs_Add, snmpInBadVer-
       sions, snmpInBadVersions_Add,

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       int snmpInASNParseErrs(void);

       int snmpInASNParseErrs_Add(int Num);

       int snmpInBadVersions(void);

       int snmpInBadVersions_Add(int Num);

DESCRIPTION
       snmpInASNParseErrs() and  snmpInBadVersions()  return  the
       number  of  ASN  parsing  errors,  and  bad SNMP versions,
       encountered by the library.

       snmpInASNParseErrs_Add() and snmpInBadVersions_Add() allow
       a  program  to  increment  the  appropriate counter by Num
       occurances.

RETURN VALUES
       All functions return the (new) total number of errors.

RFCS
       Related RFCs: 1065, 1066, 1067
       Related SNMPv2 RFCs: 1901, 1902, 1902, 1904,  1905,  1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp

SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)



SNMP_PACKET_DUMP(3)                           SNMP_PACKET_DUMP(3)


NAME
       snmp_dump,  snmp_dump_packet - SNMP Network Packet Dumping
       Routines

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       void snmp_dump_packet(int i);

       void snmp_dump(unsigned char * Buf, int BufLen, char *How,
       struct in_addr Who);

DESCRIPTION
       snmp_dump_packet()  sets  the boolean value for whether or
       not snmp_dump() should do anything to the value of i.

       snmp_dump() prints BufLen bytes  of  Buf,  with  a  header
       describing  where  it  is  going from/to.  The destination
       machine is Who, and a description of how the data is  mov-
       ing is passed as How.

       snmp_dump_packet(Buf, 15, "Sending", &from)

       would result in a header that says

       Sending 15 bytes <-> host.in.from:

RFCS
       Related RFCs: 1065, 1066, 1067
       Related  SNMPv2  RFCs: 1901, 1902, 1902, 1904, 1905, 1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp

SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)



SNMP_OID(3)                                           SNMP_OID(3)


NAME
       snmp_oid  -  Format  of  specifying variable names to SNMP
       tools.

SYNOPSIS
       system.sysdescr.0

DESCRIPTION
       Variable names are in the  format  of  Object  Identifiers
       (ASN.1).   There  are  several  methods of representation.
       Each variable name is given in the format  of  A.B.C.D...,
       where  A,  B,  C,  and  D are subidentifiers in one of two
       forms of notation.  Each subidentifier may be encoded as a
       decimal  integer, or a symbol as found in the RFC1066 MIB.
       The case of the symbols is not significant.
       If there is no leading "." in the variable name, the  name
       will   be   formed   as   if  having  been  preceded  with
       "iso.org.dod.internet.mgmt.mib.".  A "."  must  be  placed
       before  the first variable if the user is to fully specify
       the name.  For example:

       1.1.0 system.sysDescr.0 and 1.sysDescr.0

       all refer to the same variable name.  Likewise:

       .1.3.6.1.2.1.1.1.0     .iso.org.dod.internet.mgmt.mib.sys-
       tem.sysdescr.0 .1.3.6.1.2.1.1.sysdescr.0

       All refer to the same variable name.

       The  description of the variables in the MIB is given in a
       file named mib.txt in the current directory or in  a  file
       named   in   the   environment   variable  MIBFILE  or  in
       /etc/mib.txt .  These files  are  searched  in  the  above
       order.   The  files  are in the ASN.1 notation and use the
       OBJECT TYPE macro defined in RFC 1065.  Most of  the  file
       describing  the  RFC  1066  MIB  is pulled out of RFC 1066
       without change.

BUGS
       The mibfile parser  is  not  expected  to  handle  bizarre
       (although  correct) interpretations of the ASN.1 notation.

RFCS
       Related RFCs: 1065, 1066, 1067
       Related SNMPv2 RFCs: 1901, 1902, 1902, 1904,  1905,  1906,
       1907, 1908, 1909

RELATED URLS
       CMU Networking Group: http://www.net.cmu.edu/
       CMU SNMP Home Page: http://www.net.cmu.edu/projects/snmp

SEE ALSO
       snmp_api(3),      snmp_api_errors(3),      snmp_client(3),
       snmp_coexistance(3),     snmp_error(3),     snmp_extra(3),
       snmp_mib(3),      snmp_mibii(3),      snmp_mini_client(3),
       snmp_msg(3),       snmp_packet_dump(3),       snmp_pdu(3),
       snmp_vars(3), snmp_version_info(3), snmp_oid(5) snmp(3)

===========================================================================

NAME
       snmp_api_error, snmp_api_errno - Deal with SNMP API Errors

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       char *snmp_api_error(int errno);
       int snmp_api_errno(void);

DESCRIPTION
       snmp_api_errno() returns the current SNMP API error status.
       snmp_api_error()  returns a string describing what the error
       represents.

ERROR VALUES
       The possible error values are:

       SNMPERR_GENERR
          A generic occured.

       SNMPERR_BAD_LOCPORT
       SNMPERR_BAD_ADDRESS
       SNMPERR_BAD_SESSION
       SNMPERR_TOO_LONG
          Data too long for provided buffer

       SNMPERR_ASN_ENCODE
          There was a problem encoding the ASN1/BER stream.

       SNMPERR_ASN_DECODE
          There was a problem decoding the ASN1/BER stream.

       SNMPERR_PDU_TRANSLATION
          Unable to translate the specified PDU.

       SNMPERR_OS_ERR
          An OS error occured.  Most likely a failed malloc.

       SNMPERR_INVALID_TXTOID
          The textual oid usaed was invalid

       SNMPERR_UNABLE_TO_FIX
          Unable to fix this PDU.  Caused by the PDU not being  a
          response,  not  containing  an  error,  or the errindex
          being invalid.

       SNMPERR_UNSUPPORTED_TYPE
          An unsupported OID type was encountered.

       SNMPERR_PDU_PARSE
          The PDU was decoded, but it contained  something
          unexpected.

       SNMPERR_PACKET_ERR
       SNMPERR_NO_RESPONSE

NOTES
       The error message is stored in the data segment of the library.
       Do not attempt to free() it.



NAME
       snmp_synch_input,  snmp_synch_response,  snmp_synch_setup  - SNMP
       Session Synchronization

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       int snmp_synch_input (int Operation,
                             struct  snmp_session *Session,
                             int RequestID,
                             struct snmp_pdu *PDU,
                             void * Magic);

       int snmp_synch_response (struct snmp_session *Session,
                                struct snmp_pdu *PDU,
                                struct snmp_pdu **ResponseP);

       void snmp_synch_setup (struct snmp_session *Session);

       snmp_synch_input() is called when a registered session receives
       an update.  Operation specifies what has occured (TIMED_OUT or
       RECEIVED_MESSAGE).  Session is the session, RequestID is the
       reqid of the PDU in question, PDU is the PDU in question, and
       Magic is a pointer to the current state of that session.
       snmp_synch_response() is a quick way to send PDU over session
       Session and wait for a response. The response will be pointed to
       by ResponsePDUP.

       snmp_synch_setup() sets up session Session for use with these
       functions.

RETURN VALUES
       snmp_synch_input() returns 0 upon error, 1 otherwise.
       snmp_synch_response() returns either STAT_SUCCESS, STAT_TIMEOUT,
       or STAT_ERROR.




NAME
       snmp_coexist_V2toV1, snmp_coexist_V1toV2 - Translate SNMP packets

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       int snmp_coexist_V2toV1(struct snmp_pdu PDU);
       int snmp_coexist_V1toV2(struct snmp_pdu PDU);

DESCRIPTION
       Both functions convert the specified packet to the appropriate
       version.  These functions are designed to work in an SNMP agent,
       and convert requests to allow a V1 agent to communicate with a V2
       manager.

RETURN VALUE
       All functions return 1 upon success, 0 otherwise.

ERRORS
       If any of these return unsuccessfully, snmp_api_error() will be
       set.

WARNINGS
       These functions have never been tested.



NAME
       snmp_errstring - Decode returned SNMP error condition

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       char *snmp_errstring(int errstat);

DESCRIPTION
       This function returns a textual description of the error
       condition in the PDU returned by the queried SNMP agent.

RETURN VALUE
       A string containing the error message.

NOTES
       The error message is stored in the data segment of the library.
       Do not attempt to free() it.




NAME
       uptime_string, myaddress, mib_TxtToOid, mib_OidToTxt -
       Useful functions

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       char *uptime_string (unsigned int timeticks, char * buf);

       unsigned int myaddress (void);

       int mib_TxtToOid (char *Buf, oid **OidP, int *LenP);
       int mib_OidToTxt (oid *O, int OLen, char *Buf, int BufLen);

DESCRIPTION
       uptime_string() converts the value of timeticks into a readable
       string.  This function assumes that timeticks is of SMI type
       TimeTicks (Centi-seconds).

       myaddress() returns the IP address of the current active
       interface.

       mib_TxtToOid and mib_OidToTxt convert between ASN oids and
       textual strings (IE: ".1.3.6").

       mib_TxtToOid allocates space for the ASN oid, and this space
       must later be free()'d.

       mib_OidToTxt starts filling the specified buffer (of length
       BufLen) until it runs out of space, or finishes.

RETURN VALUE
       uptime_string() returns the filled buffer.
       myaddress() returns the IP address, or 0.
       mib_TxtToOid() and mib_OidToTxt() return 1 upon success,
       0 otherwise.



NAME
       snmpInASNParseErrs,  snmpInASNParseErrs_Add,  snmpInBadVersions,
       snmpInBadVersions_Add,

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       int snmpInASNParseErrs (void);
       int snmpInASNParseErrs_Add (int Num);
       int snmpInBadVersions (void);
       int snmpInBadVersions_Add (int Num);

DESCRIPTION
       snmpInASNParseErrs() and snmpInBadVersions() return the number
       of ASN parsing errors, and bad SNMP versions, encountered by the
       library.

       snmpInASNParseErrs_Add() and snmpInBadVersions_Add() allow a
       program to increment the appropriate counter by Num occurances.

RETURN VALUES
       All functions return the (new) total number of errors.




NAME
       init_mini_snmp_client,  close_mini_snmp_client,
       snmp_mini_response_len, snmp_mini_open,
       snmp_mini_close,        snmp_mini_set_int,
       snmp_mini_set_str,      snmp_mini_get,
       snmp_mini_getnext  - SNMP Mini Client

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       void init_mini_snmp_client (int Size);
       void close_mini_snmp_client (void);
       int snmp_mini_response_len (int Index);
       void *snmp_mini_open (char *Host, int port, char *community);
       void snmp_mini_close (void *MiniSession);
       int  snmp_mini_set_int (char *Host, char *Community, oid *Query,
                               int QueryLen, int Value, void *MiniSession);
       int  snmp_mini_set_str (char *Host, char *Community, oid *Query,
                               int QueryLen, char *Value, int ValueLen,
                               void *MiniSession);
       void **snmp_mini_get (char *Host, char *Community,
                             int NumQueries, oid **Queries,
                             int *QueryLens, void *MiniSession);
       int  snmp_mini_getnext (char *Host, char *Community, oid *Query,
                               int QueryLen, oid *ResponseOID,
                               void **ResponseData, void *MiniSession);

DESCRIPTION
       The SNMP mini-client is a quick way to send a few requests to a
       remote SNMP agent.  The client takes care of memory allocation /
       deallocation for all returned data.  The only thing the user must
       deal with is the specification of what OIDs to fetch.

       init_mini_snmp_client() initializes the mini-client. The Size
       argument must be greater than the max number of items you will
       fetch during one snmp_mini_client_get() call. This initializes
       the return array to the appropriate size.

       close_mini_snmp_client() Cleans up any memory still in use by
       the mini-client.  Once called, any data that was ever returned
       by the mini-client, if not copied, is invalid.

       snmp_mini_response_len() allows one to fetch the length of the
       returned data.  Index is the index into the returned array of
       responses.

       snmp_mini_open() and snmp_mini_close() allow the user to open and
       close a connection to a host.  While all of the mini-client func-
       tions will also do this, by opening the connection first with
       snmp_mini_open(), the connection may be on an alternate port.
       Opening the connection once and using it over and over again will
       also save the overhead of establishing the connection again and
       again.

       snmp_mini_set_int() and snmp_mini_set_str() will send an SNMP SET
       request to the host specified by Host, using community string
       Community, setting the OID Query of length QueryLen to Value.
       MiniSession may be used instead of Host and Community.
       MiniSession is what is returned by snmp_mini_open().

       snmp_mini_get() sends NumQueries SNMP GET requests to Host with
       community string Community (or uses session MiniSession). The
       OIDs to fetch are in the array Queries, and the OID lengths are
       in the array QueryLens.  If successful, the returned array
       contains all of the responses.  Returned array index X is the
       response to Query array index X.

       snmp_mini_getnext() sends an SNMP GETNEXT request to Host with
       community string Community (or uses session MiniSession).  The
       next OID is placed in ResponseOID and it's length is returned.
       The data pertaining to that oid is pointed to by ResponseData.

ERRORS
       If any of these return unsuccessfully, snmp_api_error() will be
       set.

NOTES
       The set commands have not been tested extensively.


NAME
       snmp_msg_Encode, snmp_msg_Decode - Encode and Decode an ASN1/BER
                                          encoded SNMP packet

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       unsigned char *snmp_msg_Encode (unsigned char *Buf,
                                       int           *BufLenP,
                                       unsigned char *Community,
                                       int            CommLen,
                                       int            Version,
                                       struct snmp_pdu *PDU);

       unsigned char *snmp_msg_Decode (unsigned char *Buf,
                                       int           *BufLenP,
                                       unsigned char *Community,
                                       int           *CommLen,
                                       int           *Version,
                                       struct snmp_pdu *PDU);

DESCRIPTION
       These functions encode/decode an SNMP PDU to/from an ASN1/BER
       stream.  Buf points to a buffer containing (or about to contain)
       the stream, and BuflenP points to the number of bytes left in the
       buffer.  Community is the community string to use (length
       CommLen).  When decoding, this buffer is filled, and must contain
       enough space for the data.  Version is the version (or is set to
       the version) of this SNMP transaction.  PDU is an empty PDU
       structure to fill in with the decoded data.

RETURN VALUES
       Upon error, both functions return NULL.  Otherwise, they return a
       pointer to the next byte in Buf, and set BufLenP to the number of
       bytes remaining in the buffer.

ERRORS
       If any of these return unsuccessfully, snmp_api_error() will be
       set.

NOTES
       ASN parsing errors are counted and available via
       snmpInASNParseErrs(3) and snmpInBadVersions(3)






NAME
       snmp_oid - Format of specifying variable names to SNMP tools.

SYNOPSIS
       system.sysdescr.0

DESCRIPTION
       Variable names are in the format of Object Identifiers (ASN.1).
       There are several methods of representation. Each variable name
       is given in the format of A.B.C.D..., where A, B, C, and D are
       subidentifiers in one of two forms of notation. Each subidentifier
       may be encoded as a decimal integer, or a symbol as found in the
       RFC1066 MIB.  The case of the symbols is not significant.
       If there is no leading "." in the variable name, the name will
       be formed as if having been preceded with "iso.org.dod.inter-
       net.mgmt.mib.".  A "." must be placed before the first variable
       if the user is to fully specify the name.
       For example:
         1.1.0 system.sysDescr.0 and 1.sysDescr.0
       all refer to the same variable name.

       Likewise:
         .1.3.6.1.2.1.1.1.0
         .iso.org.dod.internet.mgmt.mib.system.sysdescr.0
         .1.3.6.1.2.1.1.sysdescr.0
       All refer to the same variable name.

       The description of the variables in the MIB is given in a file
       named mib.txt in the current directory or in a file named in the
       environment variable MIBFILE or in /etc/mib.txt. These files
       are searched in the above order. The files are in the ASN.1
       notation and use the OBJECT TYPE macro defined in RFC 1065. Most
       of the file describing the RFC 1066 MIB is pulled out of RFC 1066
       without change.

BUGS
       The mibfile parser is not expected to handle bizarre (although
       correct) interpretations of the ASN.1 notation.





NAME
       snmp_dump, snmp_dump_packet - SNMP Network Packet Dumping Routines

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       void snmp_dump_packet (int i);
       void snmp_dump (unsigned char *Buf, int BufLen, char *How,
                       struct in_addr Who);

DESCRIPTION
       snmp_dump_packet() sets the boolean value for whether or not
       snmp_dump() should do anything to the value of i.

       snmp_dump() prints BufLen bytes of Buf, with a header describing
       where it is going from/to. The destination machine is Who, and a
       description of how the data is moving is passed as How.

       snmp_dump_packet (Buf, 15, "Sending", &from)
       would result in a header that says
          Sending 15 bytes <-> host.in.from:



NAME
       snmp_pdu_create, snmp_pdu_clone,  snmp_pdu_fix,
       snmp_pdu_free,   snmp_pdu_encode, snmp_pdu_decode,
       snmp_pdu_type,   snmp_add_null_var
       - SNMP PDU Operations

SYNOPSIS
       cc [ flag ... ] file ...  -lsnmp [ library ... ]

       #include <sys/types.h>
       #include <snmp/snmp.h>

       struct snmp_pdu *snmp_pdu_new   (int Command);
       struct snmp_pdu *snmp_pdu_clone (struct snmp_pdu *Src);
       struct snmp_pdu *snmp_pdu_fix   (struct snmp_pdu *Src intcommand);
       void     snmp_pdu_free          (struct snmp_pdu *Ptr);
       u_char  *snmp_pdu_encode (u_char *Buf, int *BufLenP,
                                 struct snmp_pdu *PDU);
       u_char  *snmp_pdu_decode (u_char *Buf, int *BufLenP,
                                 struct snmp_pdu **PDUP);
       void snmp_add_null_var (struct snmp_pdu *PDU, oid *OID,
                               int OIDLen);

STRUCTURE
       The snmp_pdu structure is:
         int    command;            /* Type of this PDU */
         ipaddr address;            /* Address of peer */
         int    reqid;              /* Request id */
         int    errstat;            /* Error status */
         int    errindex;           /* Error index */

         struct variable_list *variables;/* Variable Bindings */

         /* SNMPv2 Bulk Request information */
         int    non_repeaters;
         int    max_repetitions;

         /* SNMPv1 Trap Information */
         oid   *enterprise;         /* System OID */
         int    enterprise_length;  /* System OID Length */
         ipaddr agent_addr;         /* address of object generating trap */
         int    trap_type;          /* generic trap type */
         int    specific_type;      /* specific type */
         u_int  time;               /* Uptime */


DESCRIPTION
         snmp_pdu_new() creates a new snmp_pdu structure representing the
         SNMP command command.

         snmp_pdu_clone() copies the snmp_pdu structure pointed to by Src.
         If the variable_list pointer is filled in, it is copied as well,
         so both the original and the clone point to the same variable_list.

         snmp_pdu_free() frees the snmp_pdu pointed to by Ptr, as well as
         all  variables associated with it.  This function is identical to
         snmp_free_pdu(), which is included for backwards compatibility.

         snmp_pdu_encode() and snmp_pdu_decode() encode and decode the
         snmp_pdu structure into/out of the buffer pointed to by Buf.
         BufLenP points to the length of space remaining in Buf. Upon
         successful completion, these functions return a pointer to the
         next available byte in Buf and adjusts BufLenP to reflect the
         amount of space left in the buffer after the encoding / decoding.

         snmp_pdu_fix() This functions fixes a PDU by removing the
         variable binding that was incorrect, according to the error
         index.
         This function is identical to snmp_fix_pdu(), which is included
         for backwards compatibility.

         snmp_pdu_type() This function returns a string describing the
         type of PDU pointed to by PDU.

         snmp_add_null_var() Adds a NULL variable with object identifier
         OID to the specified PDU.

RETURN VALUES
         Upon error, all functions (except snmp_pdu_free() and
         snmp_add_null_var()) return NULL.  Otherwise, the return value
         is as describe above.

ERRORS
         If any of these return unsuccessfully, snmp_api_error() will be
         set.

NOTES
         ASN parsing errors are counted and available via
         snmpInASNParseErrs(3).








NAME
         snmp_var_new,           snmp_var_clone, snmp_var_free,
         snmp_var_EncodeVarBind, snmp_var_DecodeVarBind
         - SNMP Variable List Operations

SYNOPSIS
         cc [ flag ... ] file ...  -lsnmp [ library ... ]

         #include <sys/types.h>
         #include <snmp/snmp.h>

         struct variable_list *snmp_var_new   (oid *Name, int NameLen);
         struct variable_list *snmp_var_clone (struct variable_list *Src);
         void snmp_var_free (struct variable_list *Ptr);
         u_char *snmp_var_EncodeVarBind (u_char *Buf, int *BufLenP,
                                         struct variable_list *VarList,
                                         int Version);
         u_char *snmp_var_DecodeVarBind (u_char *Buf, int *BufLenP,
                                         struct variable_list **VarListP,
                                         int Version);

STRUCTURE
         The variable_list structure is:
           struct variable_list *next_variable;  /* Next variable, or NULL */
           oid      *name;         /* OID of variable */
           int       name_length;  /* OID Length */
           u_char    type;         /* ASN type of variable */
           union {                 /* value of variable */
             int    *integer;
             u_char *string;
             oid    *objid;
           } val;
           int val_len;            /* Length of variable data */

DESCRIPTION
         snmp_var_new() creates a new variable_list structure representing
         the OID Name of length NameLen. If Name is NULL, the name oid
         will be empty.

         snmp_var_clone() copies the variable_list structure pointed to by
         Src.  If the next_variable pointer is filled in, it is copied as
         well, so both the original and the clone point to the same next
         variable_list.

         snmp_var_free() frees the variable_list pointed to by Ptr.  It
         does nothing to the variable_list pointed to by next_variable.

         snmp_var_EncodeVarBind() and snmp_var_DecodeVarBind() encode and
         decode the variable_list structure into/out of the buffer pointed
         to by Buf. BufLenP points to the length of space remaining in
         Buf.  Upon successful completion, these functions return a
         pointer to the next available byte in Buf and adjusts BufLenP to
         reflect the amount of space left in the buffer after the encoding /
         decoding. Version indicates what version of SNMP encoding should
         be used.  At this time, this is ignored.

RETURN VALUES
         Upon error, all functions (except snmp_var_free()) return NULL.
         Otherwise, the return value is as describe above.

ERRORS
         If any of these return unsuccessfully, snmp_api_error() will be
         set.

NOTES
         ASN parsing errors are counted and available via
         snmpInASNParseErrs(3).



NAME
         snmp_Version - Return version of SNMP library

SYNOPSIS
         cc [ flag ... ] file ...  -lsnmp [ library ... ]

         #include <sys/types.h>
         #include <snmp/snmp.h>

         char *snmp_Version(void);

DESCRIPTION
         This function returns a textual description of the version of
         this SNMP library.

RETURN VALUE
         A string containing the library version.

NOTES
         The version is stored in the data segment of the library.
         Do not attempt to free() it.
               

